// Generated by Bisonc++ V6.04.01 on Fri, 13 Nov 2020 13:03:52 +0100

#ifndef Parser_h_included
#define Parser_h_included

// $insert baseclass
#include "parserbase.h"
// $insert scanner.h
#include "../scanner/scanner.h"

class CronData;

class Parser: public ParserBase
{
    CronData &d_cronData;

    // $insert scannerobject
    Scanner d_scanner;
        
    public:
        Parser(std::istream &in, CronData &cronData);
        int parse();

    private:
        void addSet(std::set<int> &lhs, std::set<int> const &rhs) const;

        void error();                   // called on (syntax) errors
        int lex();                      // returns the next token from the
                                        // lexical scanner. 
        void print();                   // use, e.g., d_token, d_loc
        void exceptionHandler(std::exception const &exc);

    // support functions for parse():
        void executeAction_(int ruleNr);
        void errorRecovery_();
        void nextCycle_();
        void nextToken_();
        void print_();
};


#endif
